@@ -34,22 +34,14 @@ __date__ = "Sep 1, 2017"
 s = Settings()
 
 
-def job_wrap_function(parameters):
-    working_directory, job_id, file_path, submit_on_remote, debug = parameters
-    job_wrapper_function(
-        working_directory=working_directory,
-        job_id=job_id,
-        file_path=file_path,
-        submit_on_remote=submit_on_remote,
-        debug=debug,
-    )
-
-
 class ParallelMaster(GenericMaster):
     """
     MasterJob that handles the creation and analysis of several parallel jobs (including master and
     continuation jobs), Examples are Murnaghan or Phonon calculations
 
+    Subclasses *must* implement :method:`.collect_output()`.  Additionally :attribute:`._job_generator` must be
+    initialized with an instance of :class:`.JobGenerator` in the subclasses' `__init__`.
+
     Args:
         project (ProjectHDFio): ProjectHDFio instance which points to the HDF5 file the job is stored in
         job_name (str): name of the job, which has to be unique within the project
@@ -658,7 +650,7 @@ class ParallelMaster(GenericMaster):
                         False
                     )
                 )
-        pool.map(job_wrap_function, job_lst)
+        pool.starmap(job_wrapper_function, job_lst)
         if s.database_is_disabled:
             self.project.db.update()
         self.status.collect = True
@@ -858,6 +850,21 @@ class ParallelMaster(GenericMaster):
         else:
             return db_entry + "#" + str(self.submission_status.submitted_jobs)
 
+    def _init_child_job(self, parent):
+        """
+        Update our reference job and copy their run mode.
+
+        Args:
+            parent (:class:`.GenericJob`): job instance that this job was created from
+        """
+        self.ref_job = parent
+        if parent.server.run_mode.non_modal:
+            self.server.run_mode.non_modal = True
+        elif (
+            parent.server.run_mode.interactive
+            or parent.server.run_mode.interactive_non_modal
+        ):
+            self.server.run_mode.interactive = True
 
 class GenericOutput(OrderedDict):
     """
