@@ -44,6 +44,8 @@ from pyiron_base.server.queuestatus import (
 )
 from pyiron_base.job.external import Notebook
 
+from pyiron_base.archiving import import_archive, export_archive
+
 __author__ = "Joerg Neugebauer, Jan Janssen"
 __copyright__ = (
     "Copyright 2020, Max-Planck-Institut für Eisenforschung GmbH - "
@@ -1490,6 +1492,41 @@ class Project(ProjectPath):
                     self.db.item_update({"project": self.project_path}, entry["id"])
 
 
+    def pack(self, destination_path, csv_file_name='export.csv', compress=True):
+        """
+        by this funtion, the job table is exported to a csv file
+        and the project directory is copied and compressed (by default) to a file.
+
+        Args:
+        destination_path (str) gives the ralative path, in which the project folder is copied and the compressed
+        csv_file_name (str) is the name of the csv file used to store the project table.
+        compress (boolian), if true, the function will compress the destination_path to a tar.gz file.
+        """
+        directory_to_transfer = os.path.basename(self.path[:-1])
+        export_archive.copy_files_to_archive(
+            directory_to_transfer, destination_path, compressed=compress
+        )
+        df = export_archive.export_database(self, directory_to_transfer, destination_path)
+        df.to_csv(csv_file_name)
+
+
+    def unpack(self, origin_path, csv_file_name='export.csv', compress=True):
+        """
+        by this function, job table is imported from a given csv file,
+        and also the content of project directory is copied from a given path
+
+        Args:
+            origin_path (str): the relative path of a directory (or a compressed file without the tar.gz exention)
+                            from which the project directory is copied.
+            csv_file_name (str): the csv file from which the job_table is copied to the current project
+        """
+        csv_path = csv_file_name
+        df = pandas.read_csv(csv_path, index_col=0)
+        import_archive.import_jobs(
+            self, self.path, archive_directory=origin_path, df=df, compressed=compress
+        )
+
+
 class Creator:
     def __init__(self, project):
         self._job_factory = JobFactory(project=project)
